@@ -1,7 +1,7 @@
 package lib::disallow;
 
-our $DATE = '2016-07-09'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2016-08-24'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use strict;
 use warnings;
@@ -33,7 +33,7 @@ lib::disallow - Disallow a list of modules from being locateable/loadable
 
 =head1 VERSION
 
-This document describes version 0.25 of lib::disallow (from Perl distribution lib-filter), released on 2016-07-09.
+This document describes version 0.27 of lib::disallow (from Perl distribution lib-filter), released on 2016-08-24.
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,10 @@ feature.
 
 L<lib::filter>
 
+If an application checks the availability of modules by using L<Module::Path> or
+L<Module::Path::More> instead of trying to load them, you can try:
+L<Module::Path::Patch::Hide> or L<Module::Path::More::Patch::Hide>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
