@@ -1,8 +1,7 @@
 use File::Temp qw(tempfile);
+use Module::Path::More qw(module_path);
 use Test::More 0.98;
 
-my $has_listed_modules;
-
 sub _test_lib {
     my $which = shift;
     my %args = @_;
@@ -26,20 +25,13 @@ sub _test_lib {
             my $child_err = $?;
             if ($ent->{ok}) {
                 unless (ok(!$child_err, "require $ent->{module} ok")) {
-                    if (!$has_listed_modules++) {
-                        local @INC = (
-                            @{ $args{extra_lib} || [] },
-                            @main::ORIG_INC,
-                        );
-                        if (eval { require PERLANCAR::Module::List; 1 }) {
-                            diag explain PERLANCAR::Module::List::list_modules(
-                                "", {
-                                    list_modules=>1,
-                                    recurse=>1,
-                                    return_path=>1},
-                            );
-                        }
-                    }
+                    local @INC = (
+                        @{ $args{extra_lib} || [] },
+                        @main::ORIG_INC,
+                    );
+                    my $path = module_path(module => $ent->{module});
+                    diag "Path for module $ent->{module}: " .
+                        ($path // "(not found)");
                 }
             } else {
                 ok( $child_err, "require $ent->{module} nok");
